/*
 * This file is part of Licq, an instant messaging client for UNIX.
 * Copyright (C) 2002-2009,2011 Licq developers
 *
 * Licq is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Licq is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Licq; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef REQAUTHDLG_H
#define REQAUTHDLG_H

#include <QDialog>

#include <licq/userid.h>

class QGroupBox;
class QLabel;
class QLineEdit;
class QPushButton;

namespace LicqQtGui
{
class MLEdit;
class ProtoComboBox;

class ReqAuthDlg : public QDialog
{
   Q_OBJECT

public:
   ReqAuthDlg(const Licq::UserId& userId = Licq::UserId(), QWidget* parent = 0);

private:
   Licq::UserId myUserId;
   QPushButton* btnOk;
   QPushButton* btnCancel;
   ProtoComboBox* myProtocolCombo;
   QLineEdit* myIdEdit;
   QGroupBox* grpRequest;
   MLEdit* mleRequest;

private slots:
   void ok();
};

} // namespace LicqQtGui

#endif
